@@ -12,7 +12,7 @@ import Control.Applicative (Applicative, Alternative, (<$>))
 import Control.Arrow (first)
 import Control.Monad (MonadPlus(mplus, mzero), forever, replicateM, when)
 import Control.Monad.Cont   (MonadCont)
-import Control.Monad.Error  (MonadError)
+import Control.Monad.Except  (MonadError)
 import Control.Monad.Reader (MonadReader(ask, local), MonadTrans, ReaderT(runReaderT), mapReaderT)
 import Control.Monad.Writer (MonadWriter)
 import Control.Monad.State  (MonadState)
@@ -72,4 +72,4 @@ instance (Functor m, MonadIO m, MonadPlus m) => BotMonad (BotPartT m) where
 
 maybeZero :: (MonadPlus m) => Maybe a -> m a
 maybeZero Nothing = mzero
-maybeZero (Just a) = return a
\ No newline at end of file
+maybeZero (Just a) = return a
