@@ -7,7 +7,7 @@ module Network.IRC.Bot.Types
 import Data.ByteString          (ByteString)
 import Data.Data                (Data, Typeable)
 import Network.IRC              as I
-import Network                  (HostName)
+import Network.Socket           (HostName)
 
 data User = User
     { username   :: ByteString    -- ^ username on client system
